"use strict";
/*
 * @microeinhundert/radonis-server
 *
 * (c) Leon Seipp <l.seipp@microeinhundert.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const node_path_1 = require("node:path");
const ace_1 = require("@adonisjs/ace");
const sink_1 = require("@adonisjs/sink");
const radonis_build_1 = require("@microeinhundert/radonis-build");
const utils_1 = require("@microeinhundert/radonis-build/utils");
/**
 * A command to build the Radonis client
 */
class BuildClient extends ace_1.BaseCommand {
    static commandName = 'build:client';
    static description = 'Build the Radonis client';
    static settings = {
        loadApp: true,
        stayAlive: true,
    };
    production;
    watch;
    /**
     * The Radonis config
     */
    #config = this.application.config.get('radonis', {});
    /**
     * The public path
     */
    get #publicPath() {
        const publicDir = this.application.directoriesMap.get('public') || 'public';
        /**
         * Resolve path using outDir from tsconfig when building for production
         */
        if (this.production) {
            const tsConfig = new sink_1.files.JsonFile(this.application.appRoot, 'tsconfig.json');
            const compilerOutDir = tsConfig.get('compilerOptions.outDir') || 'build';
            return (0, node_path_1.join)(this.application.appRoot, compilerOutDir, publicDir);
        }
        return (0, node_path_1.join)(this.application.appRoot, publicDir);
    }
    /**
     * The output path
     */
    get #outputPath() {
        return (0, node_path_1.join)(this.#publicPath, 'radonis');
    }
    /**
     * Run the command
     */
    async run() {
        const { client: { buildOptions }, } = this.#config;
        const entryPoints = await (0, utils_1.getEntryPoints)(this.application.resourcesPath());
        const clientBuilder = new radonis_build_1.ClientBuilder();
        clientBuilder.onBuildEnd(async (builtAssets) => {
            const assetsManifestBuilder = new radonis_build_1.AssetsManifestBuilder(builtAssets);
            const assetsManifest = assetsManifestBuilder.build();
            await (0, utils_1.writeAssetsManifestToDisk)(assetsManifest, this.#outputPath);
            this.logger.success('built the client bundle successfully');
        });
        const rebuildOnFileChanges = !!(this.watch && !this.production);
        /**
         * Build the client
         */
        await clientBuilder.build({
            entryPoints,
            appRootPath: this.application.appRoot,
            publicPath: this.#publicPath,
            outputPath: this.#outputPath,
            outputForProduction: this.production,
            rebuildOnFileChanges,
            esbuildOptions: buildOptions,
        });
        if (!rebuildOnFileChanges) {
            this.exit();
        }
    }
}
tslib_1.__decorate([
    ace_1.flags.boolean({ description: 'Whether to build for production' }),
    tslib_1.__metadata("design:type", Object)
], BuildClient.prototype, "production", void 0);
tslib_1.__decorate([
    ace_1.flags.boolean({ description: 'Whether to automatically build on file changes' }),
    tslib_1.__metadata("design:type", Object)
], BuildClient.prototype, "watch", void 0);
exports.default = BuildClient;
//# sourceMappingURL=BuildClient.js.map