"use strict";
/*
 * @microeinhundert/radonis-server
 *
 * (c) Leon Seipp <l.seipp@microeinhundert.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssetsManager = void 0;
const utils_1 = require("@microeinhundert/radonis-build/utils");
const radonis_types_1 = require("@microeinhundert/radonis-types");
/**
 * Service for managing assets
 */
class AssetsManager {
    /**
     * The singleton instance
     */
    static instance;
    /**
     * Get the singleton instance
     */
    static getSingletonInstance(...args) {
        return (AssetsManager.instance = AssetsManager.instance ?? new AssetsManager(...args));
    }
    /**
     * The public path
     */
    #publicPath;
    /**
     * The assets manifest
     */
    #assetsManifest;
    /**
     * The required islands
     */
    #requiredIslands;
    constructor(application) {
        this.#publicPath = application.publicPath('radonis');
        this.#assetsManifest = [];
        this.#setDefaults();
    }
    /**
     * The required assets
     */
    get requiredAssets() {
        return this.#assetsManifest.reduce((assets, asset) => {
            if (asset.type === radonis_types_1.AssetType.ClientScript) {
                return [...assets, asset];
            }
            if (asset.islands.some((identifier) => this.#requiredIslands.has(identifier))) {
                return [asset, ...assets];
            }
            return assets;
        }, []);
    }
    /**
     * Require an island
     */
    requireIsland(identifier) {
        this.#requiredIslands.add(identifier);
    }
    /**
     * Read the assets manifest
     */
    async readAssetsManifest() {
        try {
            const assetsManifest = await (0, utils_1.readAssetsManifestFromDisk)(this.#publicPath);
            if (assetsManifest)
                this.#assetsManifest = assetsManifest;
        }
        catch {
            this.#assetsManifest = [];
        }
    }
    /**
     * Reset for a new request
     */
    reset() {
        this.#setDefaults();
    }
    /**
     * Set the defaults
     */
    #setDefaults() {
        this.#requiredIslands = new Set();
    }
}
exports.AssetsManager = AssetsManager;
//# sourceMappingURL=main.js.map