import type { HydrationManagerContract, Resettable } from '@microeinhundert/radonis-types';
/**
 * Service for managing hydration requirements
 */
export declare class HydrationManager implements HydrationManagerContract, Resettable {
    #private;
    /**
     * The singleton instance
     */
    static instance?: HydrationManager;
    /**
     * Get the singleton instance
     */
    static getSingletonInstance(...args: ConstructorParameters<typeof HydrationManager>): HydrationManager;
    constructor();
    /**
     * The flash messages
     */
    get flashMessages(): Record<string, string>;
    get requiredFlashMessages(): Record<string, string>;
    /**
     * Set the flash messages
     */
    setFlashMessages(flashMessages: Record<string, string>): this;
    /**
     * Require a flash message
     */
    requireFlashMessage(identifier: string): this;
    /**
     * Require all flash messages
     */
    requireAllFlashMessages(): this;
    /**
     * The messages
     */
    get messages(): Record<string, string>;
    get requiredMessages(): Record<string, string>;
    /**
     * Set the messages
     */
    setMessages(messages: Record<string, string>): this;
    /**
     * Require a message
     */
    requireMessage(identifier: string): this;
    /**
     * Require all messages
     */
    requireAllMessages(): this;
    /**
     * The routes
     */
    get routes(): Record<string, string>;
    get requiredRoutes(): Record<string, string>;
    /**
     * Set the routes
     */
    setRoutes(routes: Record<string, string>): this;
    /**
     * Require a route
     */
    requireRoute(identifier: string): this;
    /**
     * Require all routes
     */
    requireAllRoutes(): this;
    /**
     * Require flash messages, messages and routes by tokens
     */
    requireTokens(tokens: string[]): this;
    /**
     * Reset for a new request
     */
    reset(): void;
}
//# sourceMappingURL=main.d.ts.map