/// <reference types="@adonisjs/application/build/adonis-typings" />
import type { ApplicationContract } from '@ioc:Adonis/Core/Application';
import type { RadonisConfig } from '@ioc:Microeinhundert/Radonis';
import type { Globals, Hydration, ManifestManagerContract, Resettable, Route } from '@microeinhundert/radonis-types';
/**
 * Service for managing the manifest
 */
export declare class ManifestManager implements ManifestManagerContract, Resettable {
    #private;
    /**
     * The singleton instance
     */
    static instance?: ManifestManager;
    /**
     * Get the singleton instance
     */
    static getSingletonInstance(...args: ConstructorParameters<typeof ManifestManager>): ManifestManager;
    constructor(config: RadonisConfig, application: ApplicationContract);
    /**
     * The flash messages
     */
    get flashMessages(): Record<string, string>;
    get flashMessagesRequiredForHydration(): Record<string, string>;
    /**
     * Set the flash messages
     */
    setFlashMessages(flashMessages: Record<string, string>): this;
    /**
     * The messages
     */
    get messages(): Record<string, string>;
    get messagesRequiredForHydration(): Record<string, string>;
    /**
     * Set the messages
     */
    setMessages(messages: Record<string, string>): this;
    /**
     * The routes
     */
    get routes(): Record<string, string>;
    get routesRequiredForHydration(): Record<string, string>;
    /**
     * Set the routes
     */
    setRoutes(routes: Record<string, string>): this;
    /**
     * The hydration
     */
    get hydration(): Hydration;
    /**
     * Register hydration
     */
    registerHydration(hydrationRootId: string, islandIdentifier: string, props: Record<string, unknown>): this;
    /**
     * The globals
     */
    get globals(): Globals;
    /**
     * Add globals
     */
    addGlobals(globals: Globals): this;
    /**
     * The locale
     */
    get locale(): string;
    /**
     * Set the locale
     */
    setLocale(locale: string): this;
    /**
     * The current route
     */
    get route(): Route | null;
    /**
     * Set the current route
     */
    setRoute(route: Route): this;
    /**
     * Get the client manifest as JSON
     */
    getClientManifestAsJSON(): string;
    /**
     * Set the server manifest on the global scope
     */
    setServerManifestOnGlobalScope(): void;
    /**
     * Reset for a new request
     */
    reset(): void;
}
//# sourceMappingURL=main.d.ts.map