import type { Plugin, PluginEnvironment, PluginHook, PluginHooks, PluginsManagerContract } from '@microeinhundert/radonis-types';
/**
 * Service for managing plugins
 */
export declare class PluginsManager implements PluginsManagerContract {
    #private;
    /**
     * The singleton instance
     */
    static instance?: PluginsManager;
    /**
     * Get the singleton instance
     */
    static getSingletonInstance(...args: ConstructorParameters<typeof PluginsManager>): PluginsManager;
    /**
     * The registered client hooks
     */
    onInitClientHooks: PluginHook<'onInitClient'>[];
    beforeHydrateHooks: PluginHook<'beforeHydrate'>[];
    /**
     * The registered server hooks
     */
    onBootServerHooks: PluginHook<'onBootServer'>[];
    beforeRequestHooks: PluginHook<'beforeRequest'>[];
    afterRequestHooks: PluginHook<'afterRequest'>[];
    beforeRenderHooks: PluginHook<'beforeRender'>[];
    afterRenderHooks: PluginHook<'afterRender'>[];
    constructor();
    /**
     * Install one or multiple plugins
     */
    install(targetEnvironment: PluginEnvironment, ...plugins: Plugin[]): void;
    /**
     * Execute hooks of a specific type
     */
    execute<TType extends keyof PluginHooks, TBuilderValue extends unknown, TParams extends Parameters<PluginHook<TType>>>(type: TType, initialBuilderValue: TBuilderValue, ...args: TParams): Promise<TBuilderValue>;
}
//# sourceMappingURL=main.d.ts.map