/// <reference types="@adonisjs/application/build/adonis-typings" />
import type { ApplicationContract } from '@ioc:Adonis/Core/Application';
import type { HttpContextContract } from '@ioc:Adonis/Core/HttpContext';
import type { RadonisConfig } from '@ioc:Microeinhundert/Radonis';
import type { ErrorPages, FlushCallback, Globals, HeadMeta, HeadTag, RendererContract, RenderOptions, Resettable, UnwrapProps } from '@microeinhundert/radonis-types';
import type { ComponentPropsWithoutRef, ComponentType, PropsWithoutRef } from 'react';
/**
 * Service for rendering
 */
export declare class Renderer implements RendererContract, Resettable {
    #private;
    /**
     * The singleton instance
     */
    static instance?: Renderer;
    /**
     * Get the singleton instance
     */
    static getSingletonInstance(...args: ConstructorParameters<typeof Renderer>): Renderer;
    constructor(config: RadonisConfig, application: ApplicationContract);
    /**
     * Get for request
     */
    getForRequest(httpContext: HttpContextContract): this;
    /**
     * Set the head title for the current request
     */
    withHeadTitle(title: string): this;
    /**
     * Add head meta for the current request
     */
    withHeadMeta(meta: HeadMeta): this;
    /**
     * Add head tags for the current request
     */
    withHeadTags(tags: HeadTag[]): this;
    /**
     * Add globals for the current request
     */
    withGlobals(globals: Globals): this;
    /**
     * Add error pages for the current request
     */
    withErrorPages(errorPages: ErrorPages): this;
    /**
     * Add flush callbacks to be executed after
     * rendering the view for the current request
     */
    withFlushCallbacks(flushCallbacks: FlushCallback[]): this;
    /**
     * Render the view and stream the response
     */
    render<T extends PropsWithoutRef<any>>(Component: ComponentType<T>, props?: ComponentPropsWithoutRef<ComponentType<T>>, options?: RenderOptions): Promise<UnwrapProps<T>>;
    /**
     * Reset for a new request
     */
    reset(): void;
}
//# sourceMappingURL=main.d.ts.map